@@ -43,6 +43,7 @@ pub fn exec(
     // Create empty config file if does not exist
     create_dir_all(vopono_dir()?)?;
     let vopono_config_settings = ArgsConfig::get_config_file(&command)?;
+    let host_env_vars = vopono_core::util::env_vars::get_host_env_vars();
 
     let mut parsed_command = ArgsConfig::get_cli_or_config_args(command, vopono_config_settings)?;
 
@@ -154,17 +155,41 @@ pub fn exec(
             target_subnet,
             parsed_command.open_hosts.as_ref(),
             parsed_command.allow_host_access,
+            parsed_command.disable_ipv6,
         )?;
 
+        if parsed_command.firewall == vopono_core::network::firewall::Firewall::NfTables {
+            ns.setup_nftables_firewall()?;
+        }
+
         // Add local host to open hosts if allow_host_access enabled
         if parsed_command.allow_host_access {
-            let host_ip = ns.veth_pair_ips.as_ref().unwrap().host_ip;
+            let host_ip = ns
+                .veth_pair_ips
+                .as_ref()
+                .expect("No veth pair")
+                .ipv4
+                .as_ref()
+                .expect("No IPv4 host address")
+                .host_ip;
             warn!("Allowing host access from network namespace, host IP address is: {host_ip}");
             if let Some(oh) = parsed_command.open_hosts.iter_mut().next() {
                 oh.push(host_ip);
             } else {
                 parsed_command.open_hosts = Some(vec![host_ip]);
             }
+
+            // Add IPv6 host if it exists
+            if let Some(ref mut open_hosts) = parsed_command.open_hosts {
+                warn!(
+                    "Allowing host access from network namespace, host IPv6 address is: {host_ip}"
+                );
+                ns.veth_pair_ips
+                    .as_ref()
+                    .iter()
+                    .flat_map(|p| p.ipv6.as_ref())
+                    .for_each(|ipv6| open_hosts.push(ipv6.host_ip));
+            }
         }
 
         ns.add_host_masquerade(
@@ -176,6 +201,7 @@ pub fn exec(
             parsed_command.interface.clone(),
             NetworkInterface::new(ns.veth_pair.as_ref().unwrap().dest.clone())?,
             parsed_command.firewall,
+            parsed_command.disable_ipv6,
         )?;
         _sysctl = SysCtl::enable_ipv4_forwarding();
 
@@ -211,12 +237,12 @@ pub fn exec(
 
                 let mut cmd = std::process::Command::new("sudo");
                 cmd.args(args);
-                set_env_vars(&ns, forwarder.as_deref(), &mut cmd);
+                set_env_vars(&ns, forwarder.as_deref(), &mut cmd, &host_env_vars);
                 cmd.spawn()?;
             } else {
                 let mut cmd = std::process::Command::new(parsed_pucmd_ptrs[0]);
                 cmd.args(parsed_pucmd_ptrs[1..].iter());
-                set_env_vars(&ns, forwarder.as_deref(), &mut cmd);
+                set_env_vars(&ns, forwarder.as_deref(), &mut cmd, &host_env_vars);
                 cmd.spawn()?;
             };
         }
@@ -228,7 +254,6 @@ pub fn exec(
     // Forwarder is returned so it isn't dropped
 
     // Launch TCP proxy server on other threads if forwarding ports
-    // TODO: Fix when running as root
     let mut proxy = Vec::new();
     if let Some(f) = parsed_command.forward.clone() {
         if !(parsed_command.no_proxy || f.is_empty()) {
@@ -236,11 +261,28 @@ pub fn exec(
                 debug!(
                     "Forwarding port: {}, {:?}",
                     p,
-                    ns.veth_pair_ips.as_ref().unwrap().namespace_ip
+                    ns.veth_pair_ips
+                        .as_ref()
+                        .unwrap()
+                        .ipv4
+                        .as_ref()
+                        .unwrap()
+                        .namespace_ip
                 );
+
+                // TODO: Do we want IPv6 forwarding?
                 proxy.push(basic_tcp_proxy::TcpProxy::new(
                     p,
-                    std::net::SocketAddr::new(ns.veth_pair_ips.as_ref().unwrap().namespace_ip, p),
+                    std::net::SocketAddr::new(
+                        ns.veth_pair_ips
+                            .as_ref()
+                            .unwrap()
+                            .ipv4
+                            .as_ref()
+                            .unwrap()
+                            .namespace_ip,
+                        p,
+                    ),
                     false,
                 ));
             }
@@ -248,7 +290,14 @@ pub fn exec(
     }
 
     if !parsed_command.create_netns_only {
-        run_application(&parsed_command, forwarder, &ns, signals, silent)?;
+        run_application(
+            &parsed_command,
+            forwarder,
+            &ns,
+            signals,
+            silent,
+            &host_env_vars,
+        )?;
     } else {
         info!(
             "Created netns {} - will leave network namespace alive until ctrl+C received",
@@ -622,6 +671,7 @@ fn run_application(
     ns: &NetworkNamespace,
     signals: SignalsInfo,
     silent: bool,
+    host_env_vars: &std::collections::HashMap<String, String>,
 ) -> anyhow::Result<()> {
     let application = ApplicationWrapper::new(
         ns,
@@ -631,6 +681,7 @@ fn run_application(
         parsed_command.working_directory.clone().map(PathBuf::from),
         forwarder,
         silent,
+        host_env_vars,
     )?;
 
     let pid = application.handle.id();
